@@ -1,4 +1,4 @@
-runscript <- function(x, method=c('run', 'copy', 'view', 'dir'),
+runscript <- function(x, method=c('run', 'copy', 'view', 'show', 'dir'),
                       ask = TRUE, fmt="ch%02d.R", package="FinTS",
                       subdir="scripts", lib.loc=NULL){
 ##
@@ -62,6 +62,13 @@ runscript <- function(x, method=c('run', 'copy', 'view', 'dir'),
     return(invisible(Ch))
   }
 ##
+## 4a.  method == 'show'
+##
+  if(method=='show'){
+    file.show(Ch)
+    return(invisible(Ch))
+  }
+##
 ## 5.  method == 'copy'
 ##
   writeLines(ch., ch)
